@@ -1,5 +1,5 @@
 /* GNU gettext - internationalization aids
-   Copyright (C) 1995-1998, 2000-2009 Free Software Foundation, Inc.
+   Copyright (C) 1995-1998, 2000-2010, 2012 Free Software Foundation, Inc.
 
    This file was written by Peter Miller <millerp@canb.auug.org.au>
 
@@ -577,7 +577,8 @@ wrap (const message_ty *mp, ostream_t stream,
       conv = (iconv_t)(-1);
     else
       /* Avoid glibc-2.1 bug with EUC-KR.  */
-# if (__GLIBC__ - 0 == 2 && __GLIBC_MINOR__ - 0 <= 1) && !defined _LIBICONV_VERSION
+# if ((__GLIBC__ == 2 && __GLIBC_MINOR__ <= 1) && !defined __UCLIBC__) \
+     && !defined _LIBICONV_VERSION
       if (strcmp (canon_charset, "EUC-KR") == 0)
         conv = (iconv_t)(-1);
       else
@@ -800,7 +801,7 @@ wrap (const message_ty *mp, ostream_t stream,
                 {
                   char *error_message =
                     xasprintf (_("\
-internationalized messages should not contain the `\\%c' escape sequence"),
+internationalized messages should not contain the '\\%c' escape sequence"),
                                c);
                   po_xerror (PO_SEVERITY_WARNING, mp, NULL, 0, 0, false,
                              error_message);
